@@ -1,4 +1,4 @@
-import os
+import os 
 
 class DirX:
     def Directory():
@@ -19,7 +19,7 @@ class DirX:
                 raise ValueError('AB_dir must exist')
         else:
             raise ValueError('Directory must exist')
-        return [Directory]
+        return Directory
 
     def Directory_Local():
         str_x = os.getcwd().split('/')
@@ -104,4 +104,4 @@ class DirX:
                 print('-')
             except:
                 print(dataTF_list[i] + ' parquet Missing')
-        return RunCSV_Saver
\ No newline at end of file
+        return RunCSV_Saver
